@@ -1,7 +1,17 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
 from typing import Any, Dict, Optional
-from ocp_resources.resource import NamespacedResource, MissingRequiredArgumentError
+from warnings import warn
+
+from ocp_resources.resource import MissingRequiredArgumentError, NamespacedResource
+
+warn(
+    "model_registry.py module will be removed in the next release, "
+    "please import `ModelRegistry` from model_registry_modelregistry_opendatahub_io.py "
+    "or model_registry_components_platform_opendatahub_io.py instead",
+    DeprecationWarning,
+    stacklevel=2,
+)
 
 
 class ModelRegistry(NamespacedResource):
@@ -56,10 +66,10 @@ class ModelRegistry(NamespacedResource):
         super().to_dict()
 
         if not self.kind_dict and not self.yaml_file:
-            if not self.grpc:
+            if self.grpc is None:
                 raise MissingRequiredArgumentError(argument="self.grpc")
 
-            if not self.rest:
+            if self.rest is None:
                 raise MissingRequiredArgumentError(argument="self.rest")
 
             self.res["spec"] = {}
